﻿--[[-------------------------------------------------------------------------

Copyright (c) 2009 by T J Kirby 
All Rights Reserved

E-mail: < tina.kirby@swangen.co.uk  >
Web:    < http://wow.swangen.co.uk/ >

This file is a part of nUI.

    nUI is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    nUI is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with nUI.  If not, see <http://www.gnu.org/licenses/>.
	
THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR 
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT 
OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT 
LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, 
DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY 
THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE 
USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

--]]---------------------------------------------------------------------------

if not nUI then nUI = {}; end
if not nUI_InfoPanels then nUI_InfoPanels = {}; end

local CreateFrame = CreateFrame;
local MouseIsOver = MouseIsOver;

nUI_INFOMODE_GUILDCHAT  = 15;
nUI_INFOPANEL_GUILDCHAT = "nUI_InfoPanel_GuildChat";

-------------------------------------------------------------------------------
-- localization

nUI_L[nUI_INFOPANEL_GUILDCHAT]   		   		= "Info Panel: Guild Chat Display Mode"; -- this is the phrase shown in the mouseover tooltip
nUI_L[nUI_INFOPANEL_GUILDCHAT.."Label"]		= "GuildChat"; -- small word or abbreviation to show on the panel selector button

if nUI_Locale == "enGB" then
	
	nUI_L[nUI_INFOPANEL_GUILDCHAT]   		 	= "Info Panel: Guild Chat Display Mode";
	nUI_L[nUI_INFOPANEL_GUILDCHAT.."Label"]	= "GuildChat";
	
end

-------------------------------------------------------------------------------
-- default configuration for the guild chat info panel

nUI_InfoPanels[nUI_INFOPANEL_GUILDCHAT] =
{	
	enabled   = true,
	desc      = nUI_L[nUI_INFOPANEL_GUILDCHAT],		-- player friendly name/description of the panel
	label     = nUI_L[nUI_INFOPANEL_GUILDCHAT.."Label"],	-- label to use on the panel selection button face
	rotation  = nUI_INFOMODE_GUILDCHAT,			-- index or position this panel appears on/in when clicking the selector button
	full_size = true;					-- this plugin requires the entire info panel port without the button bag	
	options  =
	{
		enabled  = true,
		fontsize = 11,
		btn_size = 45,
		btn_gap  = -8,
	},
};

-------------------------------------------------------------------------------
-- master frame for the plugin

local plugin  = CreateFrame( "Frame", nUI_INFOPANEL_GUILDCHAT, nUI_Dashboard.Anchor );
local GUILDCHAT_FRAME    = ChatFrame3;
plugin.active = true;

local function onGuildChatEvent()	
        if event == "PLAYER_ENTERING_WORLD" then
        	if SIMPLE_CHAT then
	              	DEFAULT_CHAT_FRAME:AddMessage( nUI_L["nUI: You need to go to the WoW Interface menu, select the 'Social' option and turn off the 'Simple Chat' menu option to enable integrated guild chat support in nUI."], 1, 0.83, 0 );
	               	plugin.active = false;
        	end
 		plugin:UnregisterEvent( "PLAYER_ENTERING_WORLD" );		
	end	
end

plugin:SetScript( "OnEvent", onGuildChatEvent );
plugin:RegisterEvent( "PLAYER_ENTERING_WORLD" );


-------------------------------------------------------------------------------

plugin.initPanel = function( container, options )
	plugin.container = container;
	plugin.options   = options;
	if options and options.enabled then			
		container.texture = container:CreateTexture( "$parentBackdrop", "BACKGROUND" );		
		container.texture:SetAllPoints( container );		
		plugin.setEnabled( true );		
	end
end

-------------------------------------------------------------------------------

plugin.sizeChanged = function( scale, height, width )
	
	local options  = plugin.options;
	local fontsize = options.fontsize * scale;
	local btn_size = options.btn_size * scale;
	local bottom   = _G["ChatFrame3BottomButton"];
	local down     = _G["ChatFrame3DownButton"];
	local up       = _G["ChatFrame3UpButton"];
	
	plugin.scale = scale;
	
	GUILDCHAT_FRAME:SetWidth( width );
	GUILDCHAT_FRAME:SetHeight( height );
	
	-- set the size of the scroll buttons in the chat frames
	
	if plugin.btn_size ~= btn_size then
		plugin.btn_size = btn_size;

		-- size the scroll buttons

		bottom:SetWidth( btn_size );
		bottom:SetHeight( btn_size );
		
		down:SetWidth( btn_size );
		down:SetHeight( btn_size );
		
		up:SetWidth( btn_size );
		up:SetHeight( btn_size );

	end
	
	-- set the chat frame font size
	
	if plugin.fontsize ~= fontsize then
		
		plugin.fontsize = fontsize;		
		GUILDCHAT_FRAME:SetFont( nUI_L["font1"], fontsize * 2, "OUTLINE" );

	end
	
	-- set the locations of the buttons relative to their chat frame
	
	bottom:ClearAllPoints();
	bottom:SetPoint( "BOTTOMLEFT", GUILDCHAT_FRAME, "BOTTOMLEFT", -3 * scale, -8 * scale );
	
	down:ClearAllPoints();
	down:SetPoint( "BOTTOM", bottom, "TOP", 0, options.btn_gap * scale );
	
	up:ClearAllPoints();				
	up:SetPoint( "BOTTOM", down, "TOP", 0, options.btn_gap * scale );
		
end	

-------------------------------------------------------------------------------

plugin.setEnabled = function( enabled )

	local guildName;
	local windowName;
	if plugin.enabled ~= enabled then		
		plugin.enabled = enabled;
		if not enabled then
			if plugin.guildtab_parent then
				ChatFrame3Tab:SetParent( plugin.guildtab_parent );
				plugin.combattab_parent = nil;
			end

			if plugin.guildlog_parent then
				GUILDCHAT_FRAME:SetParent( plugin.guildlog_parent );
				FCF_DockFrame( GUILDCHAT_FRAME, #DOCKED_CHAT_FRAMES+1, true );
				plugin:SetScript( "OnUpdate", nil );
				plugin.guildlog_parent = nil;

				ChatFrame3Background.SetPoint = ChatFrame3Background.cachedSetPoint;
				ChatFrame3Background:ClearAllPoints();
				ChatFrame3Background:SetPoint( "TOPLEFT", GUILDCHAT_FRAME, "TOPLEFT", -2, 3 );
				ChatFrame3Background:SetPoint( "TOPRIGHT", GUILDCHAT_FRAME, "TOPRIGHT", 2, 3 );
				ChatFrame3Background:SetPoint( "BOTTOMLEFT", GUILDCHAT_FRAME, "BOTTOMLEFT", -2, -6 );
				ChatFrame3Background:SetPoint( "BOTTOMRIGHT", GUILDCHAT_FRAME, "BOTTOMRIGHT", 3, -6 );
			end
		else
			plugin.guildlog_parent = GUILDCHAT_FRAME:GetParent();
			plugin.guildtab_parent = ChatFrame3Tab:GetParent();

			if not GUILDCHAT_FRAME:IsShown() then
				GUILDCHAT_FRAME:Show();
			end
			
			-- relocate the chat frame to the area we have set aside for it on the dashboard
				
			FCF_SetLocked( GUILDCHAT_FRAME, nil );
			
			MOVING_CHAT_FRAME = GUILDCHAT_FRAME;
			
			if GUILDCHAT_FRAME.isDocked then
				FCF_UnDockFrame( GUILDCHAT_FRAME );
			end
			
			ChatFrame3Tab:SetParent( plugin.container );
			ChatFrame3Tab:Hide();
			
			ChatFrame3Background:ClearAllPoints();
			ChatFrame3Background:SetAllPoints( ChatFrame3 );
			
			ChatFrame3Background.cachedSetPoint = ChatFrame3Background.SetPoint;
			ChatFrame3Background.SetPoint       = function() end;
								
			GUILDCHAT_FRAME:StartMoving();
			GUILDCHAT_FRAME:StartSizing();
			GUILDCHAT_FRAME:SetParent( plugin.container );
			GUILDCHAT_FRAME:ClearAllPoints();
			GUILDCHAT_FRAME:SetPoint( "BOTTOMRIGHT", plugin.container, "BOTTOMRIGHT", 0, 0 );
			GUILDCHAT_FRAME:SetPoint( "TOPLEFT", plugin.container, "TOPLEFT", 0, 0 );
			GUILDCHAT_FRAME:Show();
			GUILDCHAT_FRAME:StopMovingOrSizing();
			
			MOVING_CHAT_FRAME = nil;
		
			-- clean up the combat frame
		
			ChatFrame_RemoveAllChannels( GUILDCHAT_FRAME );
			ChatFrame_RemoveAllMessageGroups( GUILDCHAT_FRAME );
			
			
               		-----------------------------------------------------------------------------------------------------------
                        -- Added to customize Chat Window - TJK
			
			-- We want to monitor chat regarding the Guild (Normal Guild Chat, Officer Chat and MOTD as appropriate)
			ChatFrame_AddMessageGroup(GUILDCHAT_FRAME, "GUILD");
			ChatFrame_AddMessageGroup(GUILDCHAT_FRAME, "GUILD_OFFICER");
		
                        -- If the player is in a guild then place the guild name in the tab window text too
                        -- If they are not then say so.			
       			if (IsInGuild()) then
        			guildName = GetGuildInfo("player");
	               	else
	               	        guildName = "Not in a Guild";
	               	end
               		windowName = format("%s [%s]","Guild Chat: ",guildName);
               		
			FCF_SetWindowName(GUILDCHAT_FRAME, windowName, 1);
               		
               		-- End of Customization Section here - TJK
               		-----------------------------------------------------------------------------------------------------------

			-- set strata, etc, for all defined frames, make sure they're all docked

			GUILDCHAT_FRAME:SetUserPlaced( true );			
					
			FCF_SetLocked( GUILDCHAT_FRAME, 1 );
			FCF_SetWindowAlpha( GUILDCHAT_FRAME, 0 );	
					
			-- relocate the chat frame buttons
		
			local bottom  = _G["ChatFrame3BottomButton"];
			local down    = _G["ChatFrame3DownButton"];
			local up      = _G["ChatFrame3UpButton"];
			
			bottom:SetAlpha( 0 );			
			down:SetAlpha( 0 );			
			up:SetAlpha( 0 );
				
			-- set method to show or hide the scroll buttons based on whether or
			-- not the mouse is in the frame
			
			GUILDCHAT_FRAME.showButtons = function( enabled )
		
				if enabled ~= GUILDCHAT_FRAME.buttons_visible then
					
					GUILDCHAT_FRAME.buttons_visible = enabled;
					bottom:SetAlpha( enabled and 1 or 0 );
					down:SetAlpha( enabled and 1 or 0 );
					up:SetAlpha( enabled and 1 or 0 );
				
				end
			end
			
			-- allow scrolling of the combat log frame with the mouse wheel
			
			GUILDCHAT_FRAME:EnableMouseWheel( true );	
			
			GUILDCHAT_FRAME:SetScript( "OnMouseWheel", 
				function()
					if arg1 > 0 then GUILDCHAT_FRAME:ScrollUp();
					else GUILDCHAT_FRAME:ScrollDown();
					end	
				end
			);		
		end				
	end			
end

-------------------------------------------------------------------------------

plugin.setSelected = function( selected )
	if selected ~= plugin.selected then
		plugin.selected = selected;				
		if selected then			
			local mouseover_timer = 0;			
			local function onGuildChatUpdate( who, elapsed )			
				mouseover_timer = mouseover_timer + elapsed;				
				if mouseover_timer > 0.2 then -- 5 fps is plenty fast enough to show these buttons				
					mouseover_timer = 0;				
					GUILDCHAT_FRAME.showButtons( MouseIsOver( GUILDCHAT_FRAME ) );			
				end
			end			
			plugin:SetScript( "OnUpdate", onGuildChatUpdate );		
		else			
			plugin:SetScript( "OnUpdate", nil );			
		end
	end
end

-------------------------------------------------------------------------------
